*******************************************************************************
*Decomposes income into predicted and residual components for males between
*the ages of 18 and 55
*******************************************************************************

capture log close
clear
set mem 8000000
global aejfinalcode = "INSERT DIRECTORY PATH WITH DATA PRODUCED BY AEJ_YEARN.DO HERE"
cd $aejfinalcode
set more off, permanently
log using aej_mincer_revise, replace


************
*Bolivia
************

use yearn_bolivia, clear
destring folio, replace
keep if (yepcip<. & educ<.)
keep if (male==1 & age>=18 & age<=55) /*men between the ages of 18 and 55*/
gen exper=age-educ-6
replace exper=0 if exper<0
gen exper2=exper^2
replace yepcip=ln(yepcip)

foreach X of num 1/5 {
	gen educ`X'=.
}

replace educ1=1 if educ<=4
recode educ1 (.=0)

replace educ2=1 if (educ>4 & educ<=8)
recode educ2 (.=0)

replace educ3=1 if (educ>8 & educ<=11)
recode educ3 (.=0)

replace educ4=1 if (educ==12)
recode educ4 (.=0)

replace educ5=1 if educ>12
recode educ5 (.=0)

egen test=rowtotal (educ1 educ2 educ3 educ4 educ5)
summ test 
count
drop test

gen exper3=exper^3
gen exper4=exper^4

foreach X of num 1/5 {
	gen expXeduc`X'=exper*educ`X'
	gen exp2Xeduc`X'=exper2*educ`X'
	gen exp3Xeduc`X'=exper3*educ`X'
	gen exp4Xeduc`X'=exper4*educ`X'
}

*fix weights so that they still aggregate properly in the more restricted sample

drop ww
sort admin1 admin3 
save temp, replace

drop obs
gen obs=1
collapse (sum) obs (mean) pop00, by(admin1 admin3)
egen double total=sum(pop00)
gen ww=1000*((pop00/obs)/total)
keep ww admin1 admin3 obs
sort admin1 admin3 
merge admin1 admin3 using temp, uniqmaster
tab _merge
drop _merge
sum ww
egen test=sum(ww)
tab test
drop test

regress yepcip expXeduc* exp2Xeduc* exp3Xeduc* exp4Xeduc* [aw=ww] 
gen xb= _b[expXeduc1]*expXeduc1+_b[expXeduc2]*expXeduc2+_b[expXeduc3]*expXeduc3+ /*
*/ _b[expXeduc4]*expXeduc4+_b[expXeduc5]*expXeduc5 /*
*/ + _b[exp2Xeduc1]*exp2Xeduc1+_b[exp2Xeduc2]*exp2Xeduc2+_b[exp2Xeduc3]*exp2Xeduc3+ /*
*/ _b[exp2Xeduc4]*exp2Xeduc4+_b[exp2Xeduc5]*exp2Xeduc5 /*
*/ + _b[exp3Xeduc1]*exp3Xeduc1+_b[exp3Xeduc2]*exp3Xeduc2+_b[exp3Xeduc3]*exp3Xeduc3 /*
*/ +  _b[exp3Xeduc4]*exp3Xeduc4+_b[exp3Xeduc5]*exp3Xeduc5+ /*
*/ _b[exp4Xeduc1]*exp4Xeduc1+_b[exp4Xeduc2]*exp4Xeduc2+_b[exp4Xeduc3]*exp4Xeduc3+ /*
*/ _b[exp4Xeduc4]*exp4Xeduc4+_b[exp4Xeduc5]*exp4Xeduc5
gen yres=yepcip-xb
keep educ   yepcip yres admin* obs ww pop00 xb              
gen cntry="BL"
summ
save ryBL, replace


***********
*Brazil
***********
use yearn_brazil, clear
keep if (yepcip<. & educ<.)
keep if (male==1 & age>=18 & age<=55) /*men between the ages of 18 and 55*/
gen exper=age-educ-6
replace exper=0 if exper<0
gen exper2=exper^2
replace yepcip=ln(yepcip)

foreach X of num 1/5 {
	gen educ`X'=.
}

replace educ1=1 if educ<=4
recode educ1 (.=0)

replace educ2=1 if (educ>4 & educ<=8)
recode educ2 (.=0)

replace educ3=1 if (educ>8 & educ<=11)
recode educ3 (.=0)

replace educ4=1 if (educ==12)
recode educ4 (.=0)

replace educ5=1 if educ>12
recode educ5 (.=0)


gen exper3=exper^3
gen exper4=exper^4

foreach X of num 1/5 {
	gen expXeduc`X'=exper*educ`X'
	gen exp2Xeduc`X'=exper2*educ`X'
	gen exp3Xeduc`X'=exper3*educ`X'
	gen exp4Xeduc`X'=exper4*educ`X'
}

drop ww
sort admin1 admin3 
save temp, replace

drop obs
gen obs=1
collapse (sum) obs (mean) pop00, by(admin1 admin3)
egen double total=sum(pop00)
gen ww=1000*((pop00/obs)/total)
keep ww admin1 admin3 obs
sort admin1 admin3 
merge admin1 admin3 using temp, uniqmaster
tab _merge
drop _merge
sum ww
egen test=sum(ww)
tab test
drop test

regress yepcip expXeduc* exp2Xeduc* exp3Xeduc* exp4Xeduc* [aw=ww] 
gen xb= _b[expXeduc1]*expXeduc1+_b[expXeduc2]*expXeduc2+_b[expXeduc3]*expXeduc3+ /*
*/ _b[expXeduc4]*expXeduc4+_b[expXeduc5]*expXeduc5 /*
*/ + _b[exp2Xeduc1]*exp2Xeduc1+_b[exp2Xeduc2]*exp2Xeduc2+_b[exp2Xeduc3]*exp2Xeduc3+ /*
*/ _b[exp2Xeduc4]*exp2Xeduc4+_b[exp2Xeduc5]*exp2Xeduc5 /*
*/ + _b[exp3Xeduc1]*exp3Xeduc1+_b[exp3Xeduc2]*exp3Xeduc2+_b[exp3Xeduc3]*exp3Xeduc3 /*
*/ +  _b[exp3Xeduc4]*exp3Xeduc4+_b[exp3Xeduc5]*exp3Xeduc5+ /*
*/ _b[exp4Xeduc1]*exp4Xeduc1+_b[exp4Xeduc2]*exp4Xeduc2+_b[exp4Xeduc3]*exp4Xeduc3+ /*
*/ _b[exp4Xeduc4]*exp4Xeduc4+_b[exp4Xeduc5]*exp4Xeduc5
gen yres=yepcip-xb
keep educ   yepcip yres admin* obs ww pop00 xb age male             
gen cntry="BR"
summ
save ryBR, replace

***********
*Canada
***********
use yearn_canada, clear
keep if (yepcip<. & educ<.)
keep if (male==1 & age>=18 & age<=55) /*men between the ages of 18 and 55*/
gen exper=age-educ-6
replace exper=0 if exper<0
gen exper2=exper^2
replace yepcip=ln(yepcip)


foreach X of num 1/5 {
	gen educ`X'=.
}

replace educ1=1 if educ<=4
recode educ1 (.=0)

replace educ2=1 if (educ>4 & educ<=8)
recode educ2 (.=0)

replace educ3=1 if (educ>8 & educ<=12)
recode educ3 (.=0)

replace educ4=1 if (educ==13)
recode educ4 (.=0)

replace educ5=1 if educ>13
recode educ5 (.=0)


gen exper3=exper^3
gen exper4=exper^4

foreach X of num 1/5 {
	gen expXeduc`X'=exper*educ`X'
	gen exp2Xeduc`X'=exper2*educ`X'
	gen exp3Xeduc`X'=exper3*educ`X'
	gen exp4Xeduc`X'=exper4*educ`X'
}

drop ww
sort admin1  
save temp, replace

drop obs
gen obs=1
collapse (sum) obs (mean) pop00, by(admin1)
egen double total=sum(pop00)
gen ww=1000*((pop00/obs)/total)
keep ww admin1 obs
sort admin1 
merge admin1 using temp, uniqmaster
tab _merge
drop _merge
sum ww
egen test=sum(ww)
tab test
drop test

regress yepcip expXeduc* exp2Xeduc* exp3Xeduc* exp4Xeduc* [aw=ww] 
gen xb= _b[expXeduc1]*expXeduc1+_b[expXeduc2]*expXeduc2+_b[expXeduc3]*expXeduc3+ /*
*/ _b[expXeduc4]*expXeduc4+_b[expXeduc5]*expXeduc5 /*
*/ + _b[exp2Xeduc1]*exp2Xeduc1+_b[exp2Xeduc2]*exp2Xeduc2+_b[exp2Xeduc3]*exp2Xeduc3+ /*
*/ _b[exp2Xeduc4]*exp2Xeduc4+_b[exp2Xeduc5]*exp2Xeduc5 /*
*/ + _b[exp3Xeduc1]*exp3Xeduc1+_b[exp3Xeduc2]*exp3Xeduc2+_b[exp3Xeduc3]*exp3Xeduc3 /*
*/ +  _b[exp3Xeduc4]*exp3Xeduc4+_b[exp3Xeduc5]*exp3Xeduc5+ /*
*/ _b[exp4Xeduc1]*exp4Xeduc1+_b[exp4Xeduc2]*exp4Xeduc2+_b[exp4Xeduc3]*exp4Xeduc3+ /*
*/ _b[exp4Xeduc4]*exp4Xeduc4+_b[exp4Xeduc5]*exp4Xeduc5
gen yres=yepcip-xb
keep educ   yepcip yres admin* obs ww pop00 xb              
gen cntry="CA"
summ
save ryCA, replace


**********
*Chile
**********

use yearn_chile
keep if (yepcip<. & educ<.)
keep if (male==1 & age>=18 & age<=55) /*men between the ages of 18 and 55*/


gen exper=age-educ-6
replace exper=0 if exper<0
gen exper2=exper^2
replace yepcip=ln(yepcip)


foreach X of num 1/5 {
	gen educ`X'=.
}

*recall that the Chile educ variable is categorical
replace educ1=1 if (educ>=1 & educ<=4)
recode educ1 (.=0)

replace educ2=1 if (educ>4 & educ<8)
recode educ2 (.=0)

replace educ3=1 if (educ==8)
recode educ3 (.=0)

replace educ4=1 if (educ==9 | educ==10)
recode educ4 (.=0)

replace educ5=1 if educ>10
recode educ5 (.=0)


gen exper3=exper^3
gen exper4=exper^4

foreach X of num 1/5 {
	gen expXeduc`X'=exper*educ`X'
	gen exp2Xeduc`X'=exper2*educ`X'
	gen exp3Xeduc`X'=exper3*educ`X'
	gen exp4Xeduc`X'=exper4*educ`X'
}

drop ww
sort admin1  
save temp, replace

drop obs
gen obs=1
collapse (sum) obs (mean) pop00, by(admin1)
egen double total=sum(pop00)
gen ww=1000*((pop00/obs)/total)
keep ww admin1 obs
sort admin1 
merge admin1 using temp, uniqmaster
tab _merge
drop _merge
sum ww
egen test=sum(ww)
tab test
drop test
regress yepcip expXeduc* exp2Xeduc* exp3Xeduc* exp4Xeduc* [aw=ww] 
gen xb= _b[expXeduc1]*expXeduc1+_b[expXeduc2]*expXeduc2+_b[expXeduc3]*expXeduc3+ /*
*/ _b[expXeduc4]*expXeduc4+_b[expXeduc5]*expXeduc5 /*
*/ + _b[exp2Xeduc1]*exp2Xeduc1+_b[exp2Xeduc2]*exp2Xeduc2+_b[exp2Xeduc3]*exp2Xeduc3+ /*
*/ _b[exp2Xeduc4]*exp2Xeduc4+_b[exp2Xeduc5]*exp2Xeduc5 /*
*/ + _b[exp3Xeduc1]*exp3Xeduc1+_b[exp3Xeduc2]*exp3Xeduc2+_b[exp3Xeduc3]*exp3Xeduc3 /*
*/ +  _b[exp3Xeduc4]*exp3Xeduc4+_b[exp3Xeduc5]*exp3Xeduc5+ /*
*/ _b[exp4Xeduc1]*exp4Xeduc1+_b[exp4Xeduc2]*exp4Xeduc2+_b[exp4Xeduc3]*exp4Xeduc3+ /*
*/ _b[exp4Xeduc4]*exp4Xeduc4+_b[exp4Xeduc5]*exp4Xeduc5
gen yres=yepcip-xb
keep educ   yepcip yres admin*  obs ww pop00 xb
gen cntry="CI"
summ
save ryCI, replace


*****************
**Colombia
*****************

use yearn_colombia, clear
keep if (yepcip<. & educ<.)
keep if (male==1 & age>=18 & age<=55) /*men between the ages of 18 and 55*/
gen exper=age-educ-6
replace exper=0 if exper<0
gen exper2=exper^2
replace yepcip=ln(yepcip)


foreach X of num 1/5 {
	gen educ`X'=.
}

replace educ1=1 if educ<=4
recode educ1 (.=0)

replace educ2=1 if (educ>4 & educ<=8)
recode educ2 (.=0)

replace educ3=1 if (educ>8 & educ<=11)
recode educ3 (.=0)

replace educ4=1 if (educ==12)
recode educ4 (.=0)

replace educ5=1 if educ>12
recode educ5 (.=0)


gen exper3=exper^3
gen exper4=exper^4

foreach X of num 1/5 {
	gen expXeduc`X'=exper*educ`X'
	gen exp2Xeduc`X'=exper2*educ`X'
	gen exp3Xeduc`X'=exper3*educ`X'
	gen exp4Xeduc`X'=exper4*educ`X'
}

drop ww
destring admin1, replace
sort admin1  
save temp, replace

drop obs
gen obs=1
collapse (sum) obs (mean) pop00, by(admin1)
egen double total=sum(pop00)
gen ww=1000*((pop00/obs)/total)
keep ww admin1 obs
sort admin1 
merge admin1 using temp, uniqmaster
tab _merge
drop _merge
sum ww
egen test=sum(ww)
tab test
drop test

regress yepcip expXeduc* exp2Xeduc* exp3Xeduc* exp4Xeduc* [aw=ww] 
gen xb= _b[expXeduc1]*expXeduc1+_b[expXeduc2]*expXeduc2+_b[expXeduc3]*expXeduc3+ /*
*/ _b[expXeduc4]*expXeduc4+_b[expXeduc5]*expXeduc5 /*
*/ + _b[exp2Xeduc1]*exp2Xeduc1+_b[exp2Xeduc2]*exp2Xeduc2+_b[exp2Xeduc3]*exp2Xeduc3+ /*
*/ _b[exp2Xeduc4]*exp2Xeduc4+_b[exp2Xeduc5]*exp2Xeduc5 /*
*/ + _b[exp3Xeduc1]*exp3Xeduc1+_b[exp3Xeduc2]*exp3Xeduc2+_b[exp3Xeduc3]*exp3Xeduc3 /*
*/ +  _b[exp3Xeduc4]*exp3Xeduc4+_b[exp3Xeduc5]*exp3Xeduc5+ /*
*/ _b[exp4Xeduc1]*exp4Xeduc1+_b[exp4Xeduc2]*exp4Xeduc2+_b[exp4Xeduc3]*exp4Xeduc3+ /*
*/ _b[exp4Xeduc4]*exp4Xeduc4+_b[exp4Xeduc5]*exp4Xeduc5
gen yres=yepcip-xb
keep educ   yepcip yres admin* obs ww pop00 xb              
gen cntry="CO"
summ
save ryCO, replace


************
*Ecuador
***********
use yearn_ecuador, clear
keep if (yepcip<. & educ<.)
keep if (male==1 & age>=18 & age<=55) /*men between the ages of 18 and 55*/
gen exper=age-educ-6
replace exper=0 if exper<0
gen exper2=exper^2
replace yepcip=ln(yepcip)


foreach X of num 1/5 {
	gen educ`X'=.
}

replace educ1=1 if educ<=4
recode educ1 (.=0)

replace educ2=1 if (educ>4 & educ<=8)
recode educ2 (.=0)

replace educ3=1 if (educ>8 & educ<=11)
recode educ3 (.=0)

replace educ4=1 if (educ==12)
recode educ4 (.=0)

replace educ5=1 if educ>12
recode educ5 (.=0)


gen exper3=exper^3
gen exper4=exper^4

foreach X of num 1/5 {
	gen expXeduc`X'=exper*educ`X'
	gen exp2Xeduc`X'=exper2*educ`X'
	gen exp3Xeduc`X'=exper3*educ`X'
	gen exp4Xeduc`X'=exper4*educ`X'
}

drop ww
sort admin1  
save temp, replace

drop obs
gen obs=1
collapse (sum) obs (mean) pop00, by(admin1)
egen double total=sum(pop00)
gen ww=1000*((pop00/obs)/total)
keep ww admin1 obs
sort admin1 
merge admin1 using temp, uniqmaster
tab _merge
drop _merge
sum ww
egen test=sum(ww)
tab test
drop test

regress yepcip expXeduc* exp2Xeduc* exp3Xeduc* exp4Xeduc* [aw=ww] 
gen xb= _b[expXeduc1]*expXeduc1+_b[expXeduc2]*expXeduc2+_b[expXeduc3]*expXeduc3+ /*
*/ _b[expXeduc4]*expXeduc4+_b[expXeduc5]*expXeduc5 /*
*/ + _b[exp2Xeduc1]*exp2Xeduc1+_b[exp2Xeduc2]*exp2Xeduc2+_b[exp2Xeduc3]*exp2Xeduc3+ /*
*/ _b[exp2Xeduc4]*exp2Xeduc4+_b[exp2Xeduc5]*exp2Xeduc5 /*
*/ + _b[exp3Xeduc1]*exp3Xeduc1+_b[exp3Xeduc2]*exp3Xeduc2+_b[exp3Xeduc3]*exp3Xeduc3 /*
*/ +  _b[exp3Xeduc4]*exp3Xeduc4+_b[exp3Xeduc5]*exp3Xeduc5+ /*
*/ _b[exp4Xeduc1]*exp4Xeduc1+_b[exp4Xeduc2]*exp4Xeduc2+_b[exp4Xeduc3]*exp4Xeduc3+ /*
*/ _b[exp4Xeduc4]*exp4Xeduc4+_b[exp4Xeduc5]*exp4Xeduc5
gen yres=yepcip-xb
keep educ   yepcip yres admin* obs ww pop00 xb              
gen cntry="EC"
summ
save ryEC, replace

**************
*El Salvador
**************

use yearn_elsalvador, clear
keep if (yepcip<. & educ<.)
keep if (male==1 & age>=18 & age<=55) /*men between the ages of 18 and 55*/
gen exper=age-educ-6
replace exper=0 if exper<0
gen exper2=exper^2
replace yepcip=ln(yepcip)


foreach X of num 1/5 {
	gen educ`X'=.
}

replace educ1=1 if educ<=4
recode educ1 (.=0)

replace educ2=1 if (educ>4 & educ<=8)
recode educ2 (.=0)

replace educ3=1 if (educ>8 & educ<=11)
recode educ3 (.=0)

replace educ4=1 if (educ==12)
recode educ4 (.=0)

replace educ5=1 if educ>12
recode educ5 (.=0)


gen exper3=exper^3
gen exper4=exper^4

foreach X of num 1/5 {
	gen expXeduc`X'=exper*educ`X'
	gen exp2Xeduc`X'=exper2*educ`X'
	gen exp3Xeduc`X'=exper3*educ`X'
	gen exp4Xeduc`X'=exper4*educ`X'
}

drop ww
sort admin1 admin3 
save temp, replace

drop obs
gen obs=1
collapse (sum) obs (mean) pop00, by(admin1 admin3)
egen double total=sum(pop00)
gen ww=1000*((pop00/obs)/total)
keep ww admin1 admin3 obs
sort admin1 admin3 
merge admin1 admin3 using temp, uniqmaster
tab _merge
drop _merge
sum ww
egen test=sum(ww)
tab test
drop test

regress yepcip expXeduc* exp2Xeduc* exp3Xeduc* exp4Xeduc* [aw=ww] 
gen xb= _b[expXeduc1]*expXeduc1+_b[expXeduc2]*expXeduc2+_b[expXeduc3]*expXeduc3+ /*
*/ _b[expXeduc4]*expXeduc4+_b[expXeduc5]*expXeduc5 /*
*/ + _b[exp2Xeduc1]*exp2Xeduc1+_b[exp2Xeduc2]*exp2Xeduc2+_b[exp2Xeduc3]*exp2Xeduc3+ /*
*/ _b[exp2Xeduc4]*exp2Xeduc4+_b[exp2Xeduc5]*exp2Xeduc5 /*
*/ + _b[exp3Xeduc1]*exp3Xeduc1+_b[exp3Xeduc2]*exp3Xeduc2+_b[exp3Xeduc3]*exp3Xeduc3 /*
*/ +  _b[exp3Xeduc4]*exp3Xeduc4+_b[exp3Xeduc5]*exp3Xeduc5+ /*
*/ _b[exp4Xeduc1]*exp4Xeduc1+_b[exp4Xeduc2]*exp4Xeduc2+_b[exp4Xeduc3]*exp4Xeduc3+ /*
*/ _b[exp4Xeduc4]*exp4Xeduc4+_b[exp4Xeduc5]*exp4Xeduc5
gen yres=yepcip-xb
keep educ   yepcip yres admin* obs ww pop00 xb              
gen cntry="ES"
summ
save ryES, replace


***********
*Guatemala
***********

use yearn_guatemala, clear
keep if (yepcip<. & educ<.)
keep if (male==1 & age>=18 & age<=55) /*men between the ages of 18 and 55*/
gen exper=age-educ-6
replace exper=0 if exper<0
gen exper2=exper^2
replace yepcip=ln(yepcip)


foreach X of num 1/5 {
	gen educ`X'=.
}

replace educ1=1 if educ<=4
recode educ1 (.=0)

replace educ2=1 if (educ>4 & educ<=8)
recode educ2 (.=0)

replace educ3=1 if (educ>8 & educ<=11)
recode educ3 (.=0)

replace educ4=1 if (educ==12)
recode educ4 (.=0)

replace educ5=1 if educ>12
recode educ5 (.=0)


gen exper3=exper^3
gen exper4=exper^4

foreach X of num 1/5 {
	gen expXeduc`X'=exper*educ`X'
	gen exp2Xeduc`X'=exper2*educ`X'
	gen exp3Xeduc`X'=exper3*educ`X'
	gen exp4Xeduc`X'=exper4*educ`X'
}

drop ww
sort admin1 admin3 
save temp, replace

drop obs
gen obs=1
collapse (sum) obs (mean) pop00, by(admin1 admin3)
egen double total=sum(pop00)
gen ww=1000*((pop00/obs)/total)
keep ww admin1 admin3 obs
sort admin1 admin3 
merge admin1 admin3 using temp, uniqmaster
tab _merge
drop _merge
sum ww
egen test=sum(ww)
tab test
drop test

regress yepcip expXeduc* exp2Xeduc* exp3Xeduc* exp4Xeduc* [aw=ww] 
gen xb= _b[expXeduc1]*expXeduc1+_b[expXeduc2]*expXeduc2+_b[expXeduc3]*expXeduc3+ /*
*/ _b[expXeduc4]*expXeduc4+_b[expXeduc5]*expXeduc5 /*
*/ + _b[exp2Xeduc1]*exp2Xeduc1+_b[exp2Xeduc2]*exp2Xeduc2+_b[exp2Xeduc3]*exp2Xeduc3+ /*
*/ _b[exp2Xeduc4]*exp2Xeduc4+_b[exp2Xeduc5]*exp2Xeduc5 /*
*/ + _b[exp3Xeduc1]*exp3Xeduc1+_b[exp3Xeduc2]*exp3Xeduc2+_b[exp3Xeduc3]*exp3Xeduc3 /*
*/ +  _b[exp3Xeduc4]*exp3Xeduc4+_b[exp3Xeduc5]*exp3Xeduc5+ /*
*/ _b[exp4Xeduc1]*exp4Xeduc1+_b[exp4Xeduc2]*exp4Xeduc2+_b[exp4Xeduc3]*exp4Xeduc3+ /*
*/ _b[exp4Xeduc4]*exp4Xeduc4+_b[exp4Xeduc5]*exp4Xeduc5
gen yres=yepcip-xb
keep educ   yepcip yres admin* obs ww pop00 xb              
gen cntry="GT"
summ
save ryGT, replace

************
*Honduras
************

use yearn_honduras, clear
keep if (yepcip<. & educ<.)
keep if (male==1 & age>=18 & age<=55) /*men between the ages of 18 and 55*/
gen exper=age-educ-6
replace exper=0 if exper<0
gen exper2=exper^2
replace yepcip=ln(yepcip)


foreach X of num 1/5 {
	gen educ`X'=.
}

replace educ1=1 if educ<=4
recode educ1 (.=0)

replace educ2=1 if (educ>4 & educ<=8)
recode educ2 (.=0)

replace educ3=1 if (educ>8 & educ<=11)
recode educ3 (.=0)

replace educ4=1 if (educ==12)
recode educ4 (.=0)

replace educ5=1 if educ>12
recode educ5 (.=0)


gen exper3=exper^3
gen exper4=exper^4

foreach X of num 1/5 {
	gen expXeduc`X'=exper*educ`X'
	gen exp2Xeduc`X'=exper2*educ`X'
	gen exp3Xeduc`X'=exper3*educ`X'
	gen exp4Xeduc`X'=exper4*educ`X'
}

drop ww
sort admin1 admin3 
save temp, replace

drop obs
gen obs=1
collapse (sum) obs (mean) pop00, by(admin1 admin3)
egen double total=sum(pop00)
gen ww=1000*((pop00/obs)/total)
keep ww admin1 admin3 obs
sort admin1 admin3 
merge admin1 admin3 using temp, uniqmaster
tab _merge
drop _merge
sum ww
egen test=sum(ww)
tab test
drop test

regress yepcip expXeduc* exp2Xeduc* exp3Xeduc* exp4Xeduc* [aw=ww] 
gen xb= _b[expXeduc1]*expXeduc1+_b[expXeduc2]*expXeduc2+_b[expXeduc3]*expXeduc3+ /*
*/ _b[expXeduc4]*expXeduc4+_b[expXeduc5]*expXeduc5 /*
*/ + _b[exp2Xeduc1]*exp2Xeduc1+_b[exp2Xeduc2]*exp2Xeduc2+_b[exp2Xeduc3]*exp2Xeduc3+ /*
*/ _b[exp2Xeduc4]*exp2Xeduc4+_b[exp2Xeduc5]*exp2Xeduc5 /*
*/ + _b[exp3Xeduc1]*exp3Xeduc1+_b[exp3Xeduc2]*exp3Xeduc2+_b[exp3Xeduc3]*exp3Xeduc3 /*
*/ +  _b[exp3Xeduc4]*exp3Xeduc4+_b[exp3Xeduc5]*exp3Xeduc5+ /*
*/ _b[exp4Xeduc1]*exp4Xeduc1+_b[exp4Xeduc2]*exp4Xeduc2+_b[exp4Xeduc3]*exp4Xeduc3+ /*
*/ _b[exp4Xeduc4]*exp4Xeduc4+_b[exp4Xeduc5]*exp4Xeduc5
gen yres=yepcip-xb
keep educ   yepcip yres admin* obs ww pop00 xb              
gen cntry="HO"
summ
save ryHO, replace

************
*Mexico
************

use yearn_mexico, clear
keep if (yepcip<. & educ<.)
keep if (male==1 & age>=18 & age<=55) /*men between the ages of 18 and 55*/
gen exper=age-educ-6
replace exper=0 if exper<0
gen exper2=exper^2
replace yepcip=ln(yepcip)


foreach X of num 1/5 {
	gen educ`X'=.
}

replace educ1=1 if educ<=4
recode educ1 (.=0)

replace educ2=1 if (educ>4 & educ<=8)
recode educ2 (.=0)

replace educ3=1 if (educ>8 & educ<=11)
recode educ3 (.=0)

replace educ4=1 if (educ==12)
recode educ4 (.=0)

replace educ5=1 if educ>12
recode educ5 (.=0)


gen exper3=exper^3
gen exper4=exper^4

foreach X of num 1/5 {
	gen expXeduc`X'=exper*educ`X'
	gen exp2Xeduc`X'=exper2*educ`X'
	gen exp3Xeduc`X'=exper3*educ`X'
	gen exp4Xeduc`X'=exper4*educ`X'
}

drop ww
sort admin1 admin3 
save temp, replace

drop obs
gen obs=1
collapse (sum) obs (mean) pop00, by(admin1 admin3)
egen double total=sum(pop00)
gen ww=1000*((pop00/obs)/total)
keep ww admin1 admin3 obs
sort admin1 admin3 
merge admin1 admin3 using temp, uniqmaster
tab _merge
drop _merge
sum ww
egen test=sum(ww)
tab test
drop test

regress yepcip expXeduc* exp2Xeduc* exp3Xeduc* exp4Xeduc* [aw=ww] 
gen xb= _b[expXeduc1]*expXeduc1+_b[expXeduc2]*expXeduc2+_b[expXeduc3]*expXeduc3+ /*
*/ _b[expXeduc4]*expXeduc4+_b[expXeduc5]*expXeduc5 /*
*/ + _b[exp2Xeduc1]*exp2Xeduc1+_b[exp2Xeduc2]*exp2Xeduc2+_b[exp2Xeduc3]*exp2Xeduc3+ /*
*/ _b[exp2Xeduc4]*exp2Xeduc4+_b[exp2Xeduc5]*exp2Xeduc5 /*
*/ + _b[exp3Xeduc1]*exp3Xeduc1+_b[exp3Xeduc2]*exp3Xeduc2+_b[exp3Xeduc3]*exp3Xeduc3 /*
*/ +  _b[exp3Xeduc4]*exp3Xeduc4+_b[exp3Xeduc5]*exp3Xeduc5+ /*
*/ _b[exp4Xeduc1]*exp4Xeduc1+_b[exp4Xeduc2]*exp4Xeduc2+_b[exp4Xeduc3]*exp4Xeduc3+ /*
*/ _b[exp4Xeduc4]*exp4Xeduc4+_b[exp4Xeduc5]*exp4Xeduc5
gen yres=yepcip-xb
keep educ    yepcip yres admin* obs ww pop00 xb age male             
gen cntry="MX"
summ
save ryMX, replace

************
*Panama
************

use yearn_panama, clear
keep if (yepcip<. & educ<.)
keep if (male==1 & age>=18 & age<=55) /*men between the ages of 18 and 55*/
gen exper=age-educ-6
replace exper=0 if exper<0
gen exper2=exper^2
replace yepcip=ln(yepcip)


foreach X of num 1/5 {
	gen educ`X'=.
}

replace educ1=1 if educ<=4
recode educ1 (.=0)

replace educ2=1 if (educ>4 & educ<=8)
recode educ2 (.=0)

replace educ3=1 if (educ>8 & educ<=11)
recode educ3 (.=0)

replace educ4=1 if (educ==12)
recode educ4 (.=0)

replace educ5=1 if educ>12
recode educ5 (.=0)


gen exper3=exper^3
gen exper4=exper^4

foreach X of num 1/5 {
	gen expXeduc`X'=exper*educ`X'
	gen exp2Xeduc`X'=exper2*educ`X'
	gen exp3Xeduc`X'=exper3*educ`X'
	gen exp4Xeduc`X'=exper4*educ`X'
}

drop ww
sort admin1 admin3 
save temp, replace

drop obs
gen obs=1
collapse (sum) obs (mean) pop00, by(admin1 admin3)
egen double total=sum(pop00)
gen ww=1000*((pop00/obs)/total)
keep ww admin1 admin3 obs
sort admin1 admin3 
merge admin1 admin3 using temp, uniqmaster
tab _merge
drop _merge
sum ww
egen test=sum(ww)
tab test
drop test

regress yepcip expXeduc* exp2Xeduc* exp3Xeduc* exp4Xeduc* [aw=ww] 
gen xb= _b[expXeduc1]*expXeduc1+_b[expXeduc2]*expXeduc2+_b[expXeduc3]*expXeduc3+ /*
*/ _b[expXeduc4]*expXeduc4+_b[expXeduc5]*expXeduc5 /*
*/ + _b[exp2Xeduc1]*exp2Xeduc1+_b[exp2Xeduc2]*exp2Xeduc2+_b[exp2Xeduc3]*exp2Xeduc3+ /*
*/ _b[exp2Xeduc4]*exp2Xeduc4+_b[exp2Xeduc5]*exp2Xeduc5 /*
*/ + _b[exp3Xeduc1]*exp3Xeduc1+_b[exp3Xeduc2]*exp3Xeduc2+_b[exp3Xeduc3]*exp3Xeduc3 /*
*/ +  _b[exp3Xeduc4]*exp3Xeduc4+_b[exp3Xeduc5]*exp3Xeduc5+ /*
*/ _b[exp4Xeduc1]*exp4Xeduc1+_b[exp4Xeduc2]*exp4Xeduc2+_b[exp4Xeduc3]*exp4Xeduc3+ /*
*/ _b[exp4Xeduc4]*exp4Xeduc4+_b[exp4Xeduc5]*exp4Xeduc5
gen yres=yepcip-xb
keep educ   yepcip yres admin* obs ww pop00 xb age male             
gen cntry="PM"
summ
save ryPM, replace


************
*Paraguay
************

use ywage_paraguay, clear
keep if (yepcip<. & educ<.)
keep if (male==1 & age>=18 & age<=55) /*men between the ages of 18 and 55*/
gen exper=age-educ-6
replace exper=0 if exper<0
gen exper2=exper^2
replace yepcip=ln(yepcip)


foreach X of num 1/5 {
	gen educ`X'=.
}

replace educ1=1 if educ<=4
recode educ1 (.=0)

replace educ2=1 if (educ>4 & educ<=8)
recode educ2 (.=0)

replace educ3=1 if (educ>8 & educ<=11)
recode educ3 (.=0)

replace educ4=1 if (educ==12)
recode educ4 (.=0)

replace educ5=1 if educ>12
recode educ5 (.=0)


gen exper3=exper^3
gen exper4=exper^4

foreach X of num 1/5 {
	gen expXeduc`X'=exper*educ`X'
	gen exp2Xeduc`X'=exper2*educ`X'
	gen exp3Xeduc`X'=exper3*educ`X'
	gen exp4Xeduc`X'=exper4*educ`X'
}

drop ww
sort admin1 admin3 
save temp, replace

drop obs
gen obs=1
collapse (sum) obs (mean) pop00, by(admin1 admin3)
egen double total=sum(pop00)
gen ww=1000*((pop00/obs)/total)
keep ww admin1 admin3 obs
sort admin1 admin3 
merge admin1 admin3 using temp, uniqmaster
tab _merge
drop _merge
sum ww
egen test=sum(ww)
tab test
drop test

regress yepcip expXeduc* exp2Xeduc* exp3Xeduc* exp4Xeduc* [aw=ww] 
gen xb= _b[expXeduc1]*expXeduc1+_b[expXeduc2]*expXeduc2+_b[expXeduc3]*expXeduc3+ /*
*/ _b[expXeduc4]*expXeduc4+_b[expXeduc5]*expXeduc5 /*
*/ + _b[exp2Xeduc1]*exp2Xeduc1+_b[exp2Xeduc2]*exp2Xeduc2+_b[exp2Xeduc3]*exp2Xeduc3+ /*
*/ _b[exp2Xeduc4]*exp2Xeduc4+_b[exp2Xeduc5]*exp2Xeduc5 /*
*/ + _b[exp3Xeduc1]*exp3Xeduc1+_b[exp3Xeduc2]*exp3Xeduc2+_b[exp3Xeduc3]*exp3Xeduc3 /*
*/ +  _b[exp3Xeduc4]*exp3Xeduc4+_b[exp3Xeduc5]*exp3Xeduc5+ /*
*/ _b[exp4Xeduc1]*exp4Xeduc1+_b[exp4Xeduc2]*exp4Xeduc2+_b[exp4Xeduc3]*exp4Xeduc3+ /*
*/ _b[exp4Xeduc4]*exp4Xeduc4+_b[exp4Xeduc5]*exp4Xeduc5
gen yres=yepcip-xb
keep educ   yepcip yres admin* obs ww pop00 xb              
gen cntry="PA"
summ
save ryPA, replace


**************
*Peru
*************
use yearn_peru, clear
keep if (yepcip<. & educ<.)
keep if (male==1 & age>=18 & age<=55) /*men between the ages of 18 and 55*/
gen exper=age-educ-6
replace exper=0 if exper<0
gen exper2=exper^2
replace yepcip=ln(yepcip)


foreach X of num 1/5 {
	gen educ`X'=.
}

replace educ1=1 if educ<=4
recode educ1 (.=0)

replace educ2=1 if (educ>4 & educ<=8)
recode educ2 (.=0)

replace educ3=1 if (educ>8 & educ<=11)
recode educ3 (.=0)

replace educ4=1 if (educ==12)
recode educ4 (.=0)

replace educ5=1 if educ>12
recode educ5 (.=0)


gen exper3=exper^3
gen exper4=exper^4

foreach X of num 1/5 {
	gen expXeduc`X'=exper*educ`X'
	gen exp2Xeduc`X'=exper2*educ`X'
	gen exp3Xeduc`X'=exper3*educ`X'
	gen exp4Xeduc`X'=exper4*educ`X'
}

drop ww
sort admin1 admin3 
save temp, replace

drop obs
gen obs=1
collapse (sum) obs (mean) pop00, by(admin1 admin3)
egen double total=sum(pop00)
gen ww=1000*((pop00/obs)/total)
keep ww admin1 admin3 obs
sort admin1 admin3 
merge admin1 admin3 using temp, uniqmaster
tab _merge
drop _merge
sum ww
egen test=sum(ww)
tab test
drop test

regress yepcip expXeduc* exp2Xeduc* exp3Xeduc* exp4Xeduc* [aw=ww] 
gen xb= _b[expXeduc1]*expXeduc1+_b[expXeduc2]*expXeduc2+_b[expXeduc3]*expXeduc3+ /*
*/ _b[expXeduc4]*expXeduc4+_b[expXeduc5]*expXeduc5 /*
*/ + _b[exp2Xeduc1]*exp2Xeduc1+_b[exp2Xeduc2]*exp2Xeduc2+_b[exp2Xeduc3]*exp2Xeduc3+ /*
*/ _b[exp2Xeduc4]*exp2Xeduc4+_b[exp2Xeduc5]*exp2Xeduc5 /*
*/ + _b[exp3Xeduc1]*exp3Xeduc1+_b[exp3Xeduc2]*exp3Xeduc2+_b[exp3Xeduc3]*exp3Xeduc3 /*
*/ +  _b[exp3Xeduc4]*exp3Xeduc4+_b[exp3Xeduc5]*exp3Xeduc5+ /*
*/ _b[exp4Xeduc1]*exp4Xeduc1+_b[exp4Xeduc2]*exp4Xeduc2+_b[exp4Xeduc3]*exp4Xeduc3+ /*
*/ _b[exp4Xeduc4]*exp4Xeduc4+_b[exp4Xeduc5]*exp4Xeduc5
gen yres=yepcip-xb
keep educ   yepcip yres admin*  obs ww pop00 xb
gen cntry="PE"
summ
save ryPE, replace


******************
*United States
******************

use yearn_us, clear
keep if (yepcip<. & educ<.)
keep if (male==1 & age>=18 & age<=55) /*men between the ages of 18 and 55*/
gen exper=age-educ-6
replace exper=0 if exper<0
gen exper2=exper^2
replace yepcip=ln(yepcip)


foreach X of num 1/5 {
	gen educ`X'=.
}

replace educ1=1 if educ<=4
recode educ1 (.=0)

replace educ2=1 if (educ>4 & educ<=8)
recode educ2 (.=0)

replace educ3=1 if (educ>8 & educ<=11)
recode educ3 (.=0)

replace educ4=1 if (educ==12)
recode educ4 (.=0)

replace educ5=1 if educ>12
recode educ5 (.=0)


gen exper3=exper^3
gen exper4=exper^4

foreach X of num 1/5 {
	gen expXeduc`X'=exper*educ`X'
	gen exp2Xeduc`X'=exper2*educ`X'
	gen exp3Xeduc`X'=exper3*educ`X'
	gen exp4Xeduc`X'=exper4*educ`X'
}

drop ww
sort admin1 admin3 
save temp, replace

drop obs
gen obs=1
collapse (sum) obs (mean) pop00, by(admin1 admin3)
egen double total=sum(pop00)
gen ww=1000*((pop00/obs)/total)
keep ww admin1 admin3 obs
sort admin1 admin3 
merge admin1 admin3 using temp, uniqmaster
tab _merge
drop _merge
sum ww
egen test=sum(ww)
tab test
drop test

regress yepcip expXeduc* exp2Xeduc* exp3Xeduc* exp4Xeduc* [aw=ww] 
gen xb= _b[expXeduc1]*expXeduc1+_b[expXeduc2]*expXeduc2+_b[expXeduc3]*expXeduc3+ /*
*/ _b[expXeduc4]*expXeduc4+_b[expXeduc5]*expXeduc5 /*
*/ + _b[exp2Xeduc1]*exp2Xeduc1+_b[exp2Xeduc2]*exp2Xeduc2+_b[exp2Xeduc3]*exp2Xeduc3+ /*
*/ _b[exp2Xeduc4]*exp2Xeduc4+_b[exp2Xeduc5]*exp2Xeduc5 /*
*/ + _b[exp3Xeduc1]*exp3Xeduc1+_b[exp3Xeduc2]*exp3Xeduc2+_b[exp3Xeduc3]*exp3Xeduc3 /*
*/ +  _b[exp3Xeduc4]*exp3Xeduc4+_b[exp3Xeduc5]*exp3Xeduc5+ /*
*/ _b[exp4Xeduc1]*exp4Xeduc1+_b[exp4Xeduc2]*exp4Xeduc2+_b[exp4Xeduc3]*exp4Xeduc3+ /*
*/ _b[exp4Xeduc4]*exp4Xeduc4+_b[exp4Xeduc5]*exp4Xeduc5
gen yres=yepcip-xb
keep educ   yepcip yres admin* obs ww pop00 xb              
gen cntry="US"
summ
save ryUS, replace

**************
*Uruguay
**************
use yearn_uruguay, clear
keep if (yepcip<. & educ<.)
keep if (male==1 & age>=18 & age<=55) /*men between the ages of 18 and 55*/
gen exper=age-educ-6
replace exper=0 if exper<0
gen exper2=exper^2
replace yepcip=ln(yepcip)


foreach X of num 1/5 {
	gen educ`X'=.
}

replace educ1=1 if educ<=4
recode educ1 (.=0)

replace educ2=1 if (educ>4 & educ<=8)
recode educ2 (.=0)

replace educ3=1 if (educ>8 & educ<=11)
recode educ3 (.=0)

replace educ4=1 if (educ==12)
recode educ4 (.=0)

replace educ5=1 if educ>12
recode educ5 (.=0)


gen exper3=exper^3
gen exper4=exper^4

foreach X of num 1/5 {
	gen expXeduc`X'=exper*educ`X'
	gen exp2Xeduc`X'=exper2*educ`X'
	gen exp3Xeduc`X'=exper3*educ`X'
	gen exp4Xeduc`X'=exper4*educ`X'
}

drop ww
sort admin1  
save temp, replace

drop obs
gen obs=1
collapse (sum) obs (mean) pop00, by(admin1)
egen double total=sum(pop00)
gen ww=1000*((pop00/obs)/total)
keep ww admin1 obs
sort admin1 
merge admin1 using temp, uniqmaster
tab _merge
drop _merge
sum ww
egen test=sum(ww)
tab test
drop test

regress yepcip expXeduc* exp2Xeduc* exp3Xeduc* exp4Xeduc* [aw=ww] 
gen xb= _b[expXeduc1]*expXeduc1+_b[expXeduc2]*expXeduc2+_b[expXeduc3]*expXeduc3+ /*
*/ _b[expXeduc4]*expXeduc4+_b[expXeduc5]*expXeduc5 /*
*/ + _b[exp2Xeduc1]*exp2Xeduc1+_b[exp2Xeduc2]*exp2Xeduc2+_b[exp2Xeduc3]*exp2Xeduc3+ /*
*/ _b[exp2Xeduc4]*exp2Xeduc4+_b[exp2Xeduc5]*exp2Xeduc5 /*
*/ + _b[exp3Xeduc1]*exp3Xeduc1+_b[exp3Xeduc2]*exp3Xeduc2+_b[exp3Xeduc3]*exp3Xeduc3 /*
*/ +  _b[exp3Xeduc4]*exp3Xeduc4+_b[exp3Xeduc5]*exp3Xeduc5+ /*
*/ _b[exp4Xeduc1]*exp4Xeduc1+_b[exp4Xeduc2]*exp4Xeduc2+_b[exp4Xeduc3]*exp4Xeduc3+ /*
*/ _b[exp4Xeduc4]*exp4Xeduc4+_b[exp4Xeduc5]*exp4Xeduc5
gen yres=yepcip-xb
keep educ   yepcip yres admin*  obs ww pop00 xb
gen cntry="UY"
summ
save ryUY, replace


***************
*Venezuela
***************

use yearn_venezuela, clear
keep if (yepcip<. & educ<.)
keep if (male==1 & age>=18 & age<=55) /*men between the ages of 18 and 55*/
gen exper=age-educ-6
replace exper=0 if exper<0
gen exper2=exper^2
replace yepcip=ln(yepcip)


foreach X of num 1/5 {
	gen educ`X'=.
}

replace educ1=1 if educ<=4
recode educ1 (.=0)

replace educ2=1 if (educ>4 & educ<=8)
recode educ2 (.=0)

replace educ3=1 if (educ>8 & educ<=11)
recode educ3 (.=0)

replace educ4=1 if (educ==12)
recode educ4 (.=0)

replace educ5=1 if educ>12
recode educ5 (.=0)


gen exper3=exper^3
gen exper4=exper^4

foreach X of num 1/5 {
	gen expXeduc`X'=exper*educ`X'
	gen exp2Xeduc`X'=exper2*educ`X'
	gen exp3Xeduc`X'=exper3*educ`X'
	gen exp4Xeduc`X'=exper4*educ`X'
}

drop ww
sort admin1 admin3 
save temp, replace

drop obs
gen obs=1
collapse (sum) obs (mean) pop00, by(admin1 admin3)
egen double total=sum(pop00)
gen ww=1000*((pop00/obs)/total)
keep ww admin1 admin3 obs
sort admin1 admin3 
merge admin1 admin3 using temp, uniqmaster
tab _merge
drop _merge
sum ww
egen test=sum(ww)
tab test
drop test

regress yepcip expXeduc* exp2Xeduc* exp3Xeduc* exp4Xeduc* [aw=ww] 
gen xb= _b[expXeduc1]*expXeduc1+_b[expXeduc2]*expXeduc2+_b[expXeduc3]*expXeduc3+ /*
*/ _b[expXeduc4]*expXeduc4+_b[expXeduc5]*expXeduc5 /*
*/ + _b[exp2Xeduc1]*exp2Xeduc1+_b[exp2Xeduc2]*exp2Xeduc2+_b[exp2Xeduc3]*exp2Xeduc3+ /*
*/ _b[exp2Xeduc4]*exp2Xeduc4+_b[exp2Xeduc5]*exp2Xeduc5 /*
*/ + _b[exp3Xeduc1]*exp3Xeduc1+_b[exp3Xeduc2]*exp3Xeduc2+_b[exp3Xeduc3]*exp3Xeduc3 /*
*/ +  _b[exp3Xeduc4]*exp3Xeduc4+_b[exp3Xeduc5]*exp3Xeduc5+ /*
*/ _b[exp4Xeduc1]*exp4Xeduc1+_b[exp4Xeduc2]*exp4Xeduc2+_b[exp4Xeduc3]*exp4Xeduc3+ /*
*/ _b[exp4Xeduc4]*exp4Xeduc4+_b[exp4Xeduc5]*exp4Xeduc5
gen yres=yepcip-xb
keep educ   yepcip yres admin* obs ww pop00 xb age male          
gen cntry="VE"
summ
save ryVE, replace





